From fc67e008126d8b034a49ed24f6c94de2bf858981 Mon Sep 17 00:00:00 2001
From: Thomas Bruederli <thomas@roundcube.net>
Date: Mon, 14 May 2012 15:03:35 -0400
Subject: [PATCH] Larry: fix unfocused message thread row highlighting (#1488477)
---
plugins/debug_logger/debug_logger.php | 9 ++++++---
1 files changed, 6 insertions(+), 3 deletions(-)
diff --git a/plugins/debug_logger/debug_logger.php b/plugins/debug_logger/debug_logger.php
index 8cd3351..1e015c2 100644
--- a/plugins/debug_logger/debug_logger.php
+++ b/plugins/debug_logger/debug_logger.php
@@ -15,7 +15,7 @@
* Enable the plugin in config/main.inc.php and add your desired
* log types and files.
*
- * @version 1.0
+ * @version @package_version@
* @author Ziba Scott
* @website http://roundcube.net
*
@@ -106,13 +106,16 @@
if(!isset($args[1])){
// This could be extended to detect types based on the
- // file which called console. For now only rcube_imap.inc is supported
- $bt = debug_backtrace(true);
+ // file which called console. For now only rcube_imap/rcube_storage is supported
+ $bt = debug_backtrace();
$file = $bt[3]['file'];
switch(basename($file)){
case 'rcube_imap.php':
$type = 'imap';
break;
+ case 'rcube_storage.php':
+ $type = 'storage';
+ break;
default:
$type = FALSE;
break;
--
Gitblit v1.9.1